==> nrbc-1.3-sources.jar: org/example/prefect/EndcrisisnotificationResponse.java <==

package org.example.prefect;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="endnotification" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "endnotification"
})
@XmlRootElement(name = "endcrisisnotificationResponse")
public class EndcrisisnotificationResponse {

    @XmlElement(required = true)
    protected String endnotification;

    /**
     * Gets the value of the endnotification property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEndnotification() {
        return endnotification;
    }

    /**
     * Sets the value of the endnotification property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEndnotification(String value) {
        this.endnotification = value;
    }

}

==> nrbc-1.4-sources.jar: org/example/prefect/EndcrisisnotificationResponse.java <==

package org.example.prefect;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.commons.lang.builder.ToStringBuilder;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.builder.JAXBToStringBuilder;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="endnotification" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "endnotification"
})
@XmlRootElement(name = "endcrisisnotificationResponse")
public class EndcrisisnotificationResponse
    implements ToString
{

    @XmlElement(required = true)
    protected String endnotification;

    /**
     * Gets the value of the endnotification property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEndnotification() {
        return endnotification;
    }

    /**
     * Sets the value of the endnotification property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEndnotification(String value) {
        this.endnotification = value;
    }

    public void toString(ToStringBuilder toStringBuilder) {
        {
            String theEndnotification;
            theEndnotification = this.getEndnotification();
            toStringBuilder.append("endnotification", theEndnotification);
        }
    }

    public String toString() {
        final ToStringBuilder toStringBuilder = new JAXBToStringBuilder(this);
        toString(toStringBuilder);
        return toStringBuilder.toString();
    }

}
